

Exception
---------

You should be aware of the `Exception heirarchy <https://docs.python.org/3/library/exceptions.html#exception-hierarchy>`_.


Abstract Base Classes with Dunder Methods
-----------------------------------------

https://docs.python.org/3/library/collections.abc.html#collections-abstract-base-classes



Time Complexity of Data Structures
----------------------------------

You should know the time complexity of basic container operations for list,
set, and dict.

https://wiki.python.org/moin/TimeComplexity
